@@ -57,6 +57,25 @@ class submit_job(ExperimentalCommandMixIn, Command):
             print "submitted as job id:", job_id
 
 
+class resubmit_job(ExperimentalCommandMixIn, Command):
+
+    @classmethod
+    def register_arguments(self, parser):
+        parser.add_argument("SERVER")
+        parser.add_argument("JOB_ID", type=int)
+
+    def invoke(self):
+        self.print_experimental_notice()
+        server = AuthenticatingServerProxy(
+            self.args.SERVER, auth_backend=KeyringAuthBackend())
+        try:
+            job_id = server.scheduler.resubmit_job(self.args.JOB_ID)
+        except xmlrpclib.Fault, e:
+            raise CommandError(str(e))
+        else:
+            print "resubmitted as job id:", job_id
+
+
 class cancel_job(ExperimentalCommandMixIn, Command):
 
     @classmethod
